@@ -42,15 +42,7 @@ makeRepo <- function(pkgs, path, repos=getOption("repos"), type="source",
   if(!file.exists(path)) stop("Download path does not exist")
   Rversion <- twodigitRversion(Rversion)
   
-  folder <- switch(
-    type,
-    "source" = "src/contrib",
-    "win.binary" = sprintf("bin/windows/contrib/%s", Rversion),
-    "mac.binary" = sprintf("bin/macosx/contrib/%s", Rversion),
-    "mac.binary.mavericks" =  sprintf("bin/macosx/mavericks/contrib/%s", Rversion),
-    "mac.binary.leopard"= sprintf("bin/macosx/leopard/contrib/%s", Rversion),
-    stop("Type ", type, "not recognised.")
-  )
+  folder <- repoPrefix(type, Rversion)
   pkgPath <- file.path(path, folder)
   if(!file.exists(pkgPath)) {
     result <- dir.create(pkgPath, recursive=TRUE)
@@ -67,6 +59,20 @@ makeRepo <- function(pkgs, path, repos=getOption("repos"), type="source",
 
 
 
+repoPrefix <- function(type, Rversion){
+  switch(
+    type,
+    "source" = "src/contrib",
+    "win.binary" = sprintf("bin/windows/contrib/%s", Rversion),
+    "mac.binary" = sprintf("bin/macosx/contrib/%s", Rversion),
+    "mac.binary.mavericks" =  sprintf("bin/macosx/mavericks/contrib/%s", Rversion),
+    "mac.binary.leopard"= sprintf("bin/macosx/leopard/contrib/%s", Rversion),
+    stop("Type ", type, "not recognised.")
+  )
+}
+
+
+
 
 twodigitRversion <- function(R = R.version){
   paste(R$major, strsplit(R$minor, ".", fixed = TRUE)[[1L]][1L], sep = ".")
